pub enum IriRef {
Iri(IriS),
Prefixed {
prefix: String,
local: String,
},
}Expand description
An IRI reference, which can be either a full IRI or a prefixed name
Variants
Implementations
Sourceimpl IriRef
Functions for working with IriRef
impl IriRef
Functions for working with IriRef
Sourcepub fn get_iri(&self) -> Result<&IriS, IriRefError>
pub fn get_iri(&self) -> Result<&IriS, IriRefError>
Tries to get the IRI
Usually you want to use [self.get_iri_prefixmap] instead
Returns a reference to the IRI if successful, or an IriRefError if it is a prefixed name
Sourcepub fn get_iri_prefixmap(
&self,
prefixmap: &PrefixMap,
) -> Result<Cow<'_, IriS>, PrefixMapError>
pub fn get_iri_prefixmap( &self, prefixmap: &PrefixMap, ) -> Result<Cow<'_, IriS>, PrefixMapError>
Gets the IRI, resolving prefixed names using the provided PrefixMap
Returns a Cow, which is borrowed if the IriRef is already an IRI, or owned if it was a prefixed name.
If the prefixed name cannot be resolved, returns a PrefixMapError